@@ -116,6 +116,8 @@ class BaseDefinition(object):
         """Test for approximate equality."""
         if self is other:
             return True
+        if not isinstance(other, BaseDefinition):
+            return False
         if other.lons is None or other.lats is None:
             other_lons, other_lats = other.get_lonlats()
         else:
@@ -1111,7 +1113,7 @@ class AreaDefinition(BaseDefinition):
         self.ndim = 2
         self.pixel_size_x = (area_extent[2] - area_extent[0]) / float(width)
         self.pixel_size_y = (area_extent[3] - area_extent[1]) / float(height)
-        self.area_extent = tuple(area_extent)
+        self._area_extent = tuple(area_extent)
         if CRS is not None:
             self.crs_wkt = CRS(projection).to_wkt()
             self._proj_dict = None
@@ -1182,6 +1184,10 @@ class AreaDefinition(BaseDefinition):
                 self._proj_dict = proj4_str_to_dict(self.crs.to_proj4())
         return self._proj_dict
 
+    @property
+    def area_extent(self):
+        return self._area_extent
+
     def copy(self, **override_kwargs):
         """Make a copy of the current area.
 
@@ -1616,7 +1622,7 @@ class AreaDefinition(BaseDefinition):
         p = Proj(self.proj_str)
         x = self.projection_x_coords
         y = self.projection_y_coords
-        return p(y[y.size - cols], x[x.size - rows], inverse=True)
+        return p(x[cols],  y[rows], inverse=True)
 
     def lonlat2colrow(self, lons, lats):
         """Return image columns and rows for the given lons and lats.
